==> geant4.10.01.tar.gz: geant4.10.01/source/graphics_reps/src/G4VGraphicsScene.cc <==
//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
//
// $Id: G4VGraphicsScene.cc 73125 2013-08-19 07:57:38Z gcosmo $
// John Allison  19th July 1996

#include "G4VGraphicsScene.hh"

#include "G4VisExtent.hh"

G4VGraphicsScene::G4VGraphicsScene() {}

G4VGraphicsScene::~G4VGraphicsScene() {}

const G4VisExtent& G4VGraphicsScene::GetExtent() const
{
  return G4VisExtent::NullExtent;
}

==> geant4.10.04.p03.tar.gz: geant4.10.04.p03/source/graphics_reps/src/G4VGraphicsScene.cc <==
//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
//
// $Id$
// John Allison  19th July 1996

#include "G4VGraphicsScene.hh"

#include "G4VisExtent.hh"

G4VGraphicsScene::G4VGraphicsScene() {}

G4VGraphicsScene::~G4VGraphicsScene() {}

const G4VisExtent& G4VGraphicsScene::GetExtent() const
{
  static const G4VisExtent defaultExtent = G4VisExtent();
  return defaultExtent;
}
